@@ -15,7 +15,7 @@ def get_parent_module():
                 return package.split(".")[0]
 
 
-logstach_host = os.environ.get("LOGSTACH_HOST". "logstash")
+logstach_host = os.environ.get("LOGSTACH_HOST", "logstash")
 
 module_name = get_parent_module()
 logger = logging.getLogger(module_name)
